@@ -56,21 +56,21 @@ fn get_mint_decimals(bank: &Bank, mint: &Pubkey) -> Option<u8> {
 pub fn collect_token_balances(
     bank: &Bank,
     batch: &TransactionBatch,
-    mut mint_decimals: &mut HashMap<Pubkey, u8>,
+    mint_decimals: &mut HashMap<Pubkey, u8>,
 ) -> TransactionTokenBalances {
     let mut balances: TransactionTokenBalances = vec![];
     let mut collect_time = Measure::start("collect_token_balances");
 
-    for transaction in batch.transactions_iter() {
-        let account_keys = &transaction.message.account_keys;
-        let has_token_program = account_keys.iter().any(|p| is_token_program(p));
+    for transaction in batch.sanitized_transactions() {
+        let has_token_program = transaction
+            .message()
+            .account_keys_iter()
+            .any(is_token_program);
 
         let mut transaction_balances: Vec<TransactionTokenBalance> = vec![];
         if has_token_program {
-            for (index, account_id) in account_keys.iter().enumerate() {
-                if is_token_program(account_id)
-                    || transaction.message.program_ids().contains(&account_id)
-                {
+            for (index, account_id) in transaction.message().account_keys_iter().enumerate() {
+                if transaction.message().is_invoked(index) || is_token_program(account_id) {
                     continue;
                 }
 
@@ -78,7 +78,7 @@ pub fn collect_token_balances(
                     mint,
                     ui_token_amount,
                     owner,
-                }) = collect_token_balance_from_account(bank, account_id, &mut mint_decimals)
+                }) = collect_token_balance_from_account(bank, account_id, mint_decimals)
                 {
                     transaction_balances.push(TransactionTokenBalance {
                         account_index: index as u8,
